==> App-IndonesianFinanceUtils-0.06.tar.gz: App-IndonesianFinanceUtils-0.06/lib/App/IndonesianFinanceUtils.pm <==
package App::IndonesianFinanceUtils;

use 5.010001;

our $DATE = '2016-07-22'; # DATE
our $VERSION = '0.06'; # VERSION

1;
# ABSTRACT: CLIs related to Indonesian finance

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianFinanceUtils - CLIs related to Indonesian finance

=head1 VERSION

This document describes version 0.06 of App::IndonesianFinanceUtils (from Perl distribution App-IndonesianFinanceUtils), released on 2016-07-22.

=head1

This distribution contains several CLI's related to Indonesian finance:

=over

=item * L<convert-currency-using-klikbca>

=item * L<get-jisdor-rates>

=item * L<get-usd-idr-rate-from-klikbca>

=item * L<list-currency-exchange-rates-from-klikbca>

=back



=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianFinanceUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianFinanceUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianFinanceUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::IndonesianBankingUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> App-IndonesianFinanceUtils-0.07.tar.gz: App-IndonesianFinanceUtils-0.07/lib/App/IndonesianFinanceUtils.pm <==
package App::IndonesianFinanceUtils;

our $DATE = '2016-10-14'; # DATE
our $VERSION = '0.07'; # VERSION

1;
# ABSTRACT: CLIs related to Indonesian finance

__END__

=pod

=encoding UTF-8

=head1 NAME

App::IndonesianFinanceUtils - CLIs related to Indonesian finance

=head1 VERSION

This document describes version 0.07 of App::IndonesianFinanceUtils (from Perl distribution App-IndonesianFinanceUtils), released on 2016-10-14.

=head1

This distribution contains several CLI's related to Indonesian finance:

=over

=item * L<convert-currency-using-gmc>

=item * L<convert-currency-using-klikbca>

=item * L<get-jisdor-rates>

=item * L<get-usd-idr-rate-from-gmc>

=item * L<get-usd-idr-rate-from-klikbca>

=item * L<list-currency-exchange-rates-from-gmc>

=item * L<list-currency-exchange-rates-from-klikbca>

=back



=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-IndonesianFinanceUtils>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-IndonesianFinanceUtils>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-IndonesianFinanceUtils>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<App::IndonesianBankingUtils>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
